'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _command = require('@oclif/command');

var _liskCryptography = require('@liskhq/lisk-cryptography');

var _liskCryptography2 = _interopRequireDefault(_liskCryptography);

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _flags = require('../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

var _input = require('../../utils/input');

var _input2 = _interopRequireDefault(_input);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const outputPublicKeyOptionDescription = 'Includes the public key in the output. This option is provided for the convenience of node operators.'; /*
                                                                                                                                                   * LiskHQ/lisk-commander
                                                                                                                                                   * Copyright © 2017–2018 Lisk Foundation
                                                                                                                                                   *
                                                                                                                                                   * See the LICENSE file at the top-level directory of this distribution
                                                                                                                                                   * for licensing information.
                                                                                                                                                   *
                                                                                                                                                   * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                                                                                                                                   * no part of this software, including this file, may be copied, modified,
                                                                                                                                                   * propagated, or distributed except according to the terms contained in the
                                                                                                                                                   * LICENSE file.
                                                                                                                                                   *
                                                                                                                                                   * Removal or modification of this copyright notice is prohibited.
                                                                                                                                                   *
                                                                                                                                                   */


const processInputs = outputPublicKey => ({ passphrase, password }) => {
	const encryptedPassphraseObject = _liskCryptography2.default.encryptPassphraseWithPassword(passphrase, password);
	const encryptedPassphrase = _liskCryptography2.default.stringifyEncryptedPassphrase(encryptedPassphraseObject);
	return outputPublicKey ? {
		encryptedPassphrase,
		publicKey: _liskCryptography2.default.getKeys(passphrase).publicKey
	} : { encryptedPassphrase };
};

class EncryptCommand extends _base2.default {
	async run() {
		const {
			flags: {
				passphrase: passphraseSource,
				password: passwordSource,
				outputPublicKey
			}
		} = this.parse(EncryptCommand);
		const inputs = await (0, _input2.default)({
			passphrase: {
				source: passphraseSource,
				repeatPrompt: true
			},
			password: {
				source: passwordSource,
				repeatPrompt: true
			}
		});
		const result = processInputs(outputPublicKey)(inputs);
		this.print(result);
	}
}

exports.default = EncryptCommand;
EncryptCommand.flags = Object.assign({}, _base2.default.flags, {
	password: _command.flags.string(_flags2.default.password),
	passphrase: _command.flags.string(_flags2.default.passphrase),
	outputPublicKey: _command.flags.boolean({
		description: outputPublicKeyOptionDescription
	})
});

EncryptCommand.description = `
Encrypts your secret passphrase under a password.
`;

EncryptCommand.examples = ['passphrase:encrypt'];