'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _command = require('@oclif/command');

var _liskTransactions = require('@liskhq/lisk-transactions');

var _liskTransactions2 = _interopRequireDefault(_liskTransactions);

var _base = require('../../../base');

var _base2 = _interopRequireDefault(_base);

var _flags = require('../../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

var _input = require('../../../utils/input');

var _input2 = _interopRequireDefault(_input);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const processInputs = username => ({ passphrase, secondPassphrase }) => _liskTransactions2.default.registerDelegate({
	passphrase,
	secondPassphrase,
	username
}); /*
     * LiskHQ/lisk-commander
     * Copyright © 2017–2018 Lisk Foundation
     *
     * See the LICENSE file at the top-level directory of this distribution
     * for licensing information.
     *
     * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
     * no part of this software, including this file, may be copied, modified,
     * propagated, or distributed except according to the terms contained in the
     * LICENSE file.
     *
     * Removal or modification of this copyright notice is prohibited.
     *
     */
class DelegateCommand extends _base2.default {
	async run() {
		const {
			args: { username },
			flags: {
				passphrase: passphraseSource,
				'second-passphrase': secondPassphraseSource,
				'no-signature': noSignature
			}
		} = this.parse(DelegateCommand);

		const processFunction = processInputs(username);

		if (noSignature) {
			const result = processFunction({
				passphrase: null,
				secondPassphrase: null
			});
			return this.print(result);
		}

		const inputs = await (0, _input2.default)({
			passphrase: {
				source: passphraseSource,
				repeatPrompt: true
			},
			secondPassphrase: !secondPassphraseSource ? null : {
				source: secondPassphraseSource,
				repeatPrompt: true
			}
		});
		const result = processFunction(inputs);
		return this.print(result);
	}
}

exports.default = DelegateCommand;
DelegateCommand.args = [{
	name: 'username',
	required: true,
	description: 'Username to register as a delegate.'
}];

DelegateCommand.flags = Object.assign({}, _base2.default.flags, {
	passphrase: _command.flags.string(_flags2.default.passphrase),
	'second-passphrase': _command.flags.string(_flags2.default.secondPassphrase),
	'no-signature': _command.flags.boolean(_flags2.default.noSignature)
});

DelegateCommand.description = `
Creates a transaction which will register the account as a delegate candidate if broadcast to the network.
`;

DelegateCommand.examples = ['transaction:create:delegate lightcurve'];