'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _set = require('babel-runtime/core-js/set');

var _set2 = _interopRequireDefault(_set);

var _ajv = require('ajv');

var _ajv2 = _interopRequireDefault(_ajv);

var _ajvMergePatch = require('ajv-merge-patch');

var _ajvMergePatch2 = _interopRequireDefault(_ajvMergePatch);

var _browserifyBignum = require('browserify-bignum');

var _browserifyBignum2 = _interopRequireDefault(_browserifyBignum);

var _validation = require('./validation');

var _schema = require('./schema');

var schemas = _interopRequireWildcard(_schema);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var validator = new _ajv2.default({ allErrors: true }); /*
                                                         * Copyright © 2018 Lisk Foundation
                                                         *
                                                         * See the LICENSE file at the top-level directory of this distribution
                                                         * for licensing information.
                                                         *
                                                         * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                                         * no part of this software, including this file, may be copied, modified,
                                                         * propagated, or distributed except according to the terms contained in the
                                                         * LICENSE file.
                                                         *
                                                         * Removal or modification of this copyright notice is prohibited.
                                                         *
                                                         */

(0, _ajvMergePatch2.default)(validator);

validator.addFormat('signature', function (data) {
	return (/^[a-f0-9]{128}$/i.test(data)
	);
});

validator.addFormat('id', function (data) {
	return (0, _validation.isNumberString)(data) && !(0, _validation.isGreaterThanMaxTransactionId)((0, _browserifyBignum2.default)(data));
});

validator.addFormat('address', function (data) {
	try {
		(0, _validation.validateAddress)(data);
		return true;
	} catch (error) {
		return false;
	}
});

validator.addFormat('amount', function (data) {
	return (0, _validation.isNumberString)(data) && !(0, _validation.isGreaterThanMaxTransactionAmount)((0, _browserifyBignum2.default)(data));
});

validator.addFormat('publicKey', function (data) {
	try {
		(0, _validation.validatePublicKey)(data);
		return true;
	} catch (error) {
		return false;
	}
});

validator.addFormat('signedPublicKey', function (data) {
	try {
		var action = data[0];
		if (action !== '+' && action !== '-') {
			return false;
		}
		var publicKey = data.slice(1);
		(0, _validation.validatePublicKey)(publicKey);
		return true;
	} catch (error) {
		return false;
	}
});

validator.addFormat('additionPublicKey', function (data) {
	var action = data[0];
	if (action !== '+') {
		return false;
	}
	try {
		var publicKey = data.slice(1);
		(0, _validation.validatePublicKey)(publicKey);
		return true;
	} catch (error) {
		return false;
	}
});

validator.addKeyword('uniqueSignedPublicKeys', {
	type: 'array',
	compile: function compile() {
		return function (data) {
			return new _set2.default(data.map(function (key) {
				return key.slice(1);
			})).size === data.length;
		};
	}
});

validator.addSchema(schemas.baseTransaction);

exports.default = validator;